#!/bin/bash

# This helper script will handle deploying a DAX cluster
#
# /scripts/deploy-dax.sh
#

set -e

source /scripts/utils.sh
source /scripts/terraform.sh

check_access ${appsNamespace} configmaps
check_access ${appsNamespace} services

tfAdditionalVarsFile=${tfRoot}/additional_settings.auto.tfvars

echo "iam_prefix = \"${externalNamingPrefix}\"" >> ${tfAdditionalVarsFile}
echo "dax_iam_role_arn = \"${DAX_ROLE_ARN}\"" >> ${tfAdditionalVarsFile}

terraform_init
terraform_plan
terraform_apply
terraform_output

print_header "Dump output to ConfigMap"

arnConfigMapName=${namingPrefix}-arn

terraform_get arn arnValue
daxClusterEndpoint=$(jq '.cluster_address.value' output.json):$(jq '.port.value' output.json)
terraform_get read_only_policy readOnlyPolicyValue
terraform_get read_write_policy readWritePolicyValue

cat >/tmp/config.yaml <<EOF
apiVersion: v1
kind: ConfigMap
metadata:
  name: ${arnConfigMapName}
data:
  ARN: ${arnValue}
  ReadOnlyPolicy: ${readOnlyPolicyValue}
  ReadWritePolicy: ${readWritePolicyValue}
EOF

run_cmd cat "/tmp/config.yaml"
/scripts/wait-until -t 30 -i 5 true kubectl --namespace ${appsNamespace} apply -f /tmp/config.yaml
/scripts/wait-until -t 30 -i 5 true kubectl --namespace ${infraNamespace} apply -f /tmp/config.yaml

echo "Config map ${arnConfigMapName}"
/scripts/wait-until -t 30 -i 5 true kubectl --namespace ${appsNamespace} get cm ${arnConfigMapName} -o yaml
create_hostname_configmap ${namingPrefix}-endpoint ${appsNamespace} "--from-literal=endpoint=${daxClusterEndpoint}"

cprint "$0 done "
